==> ejc-accplat-impl-3.0.0-20231219.081400-23-sources.jar: com/ejianc/business/kingdee/test/InvokeTest.java <==
package com.ejianc.business.kingdee.test;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;

/**
 * @description: TODO
 * @author songlx
 * @date 2023/12/12
 * @version 1.0
 */
public class InvokeTest {

    // http://123.234.41.174:8090/k3cloud/html5/index.aspx
    //账号 ：徐慧/666666  选世纪阳光测试账套
    public static void main(String[] args) throws Exception {
        InvokeHelper.POST_K3CloudURL = "http://123.234.41.174:8090/K3Cloud/";
        String dbId = "6576a9828d11ae";
        String uid = "徐慧";
        String pwd = "666666";
        int lang = 2052;

        if (InvokeHelper.Login(dbId, uid, pwd, lang)) {

// 销售订单保存测试
// 业务对象Id
            String sFormId = "GL_VOUCHER";
            JSONObject data = new JSONObject();

            JSONObject model = new JSONObject();

            JSONObject _FAccountBookID = new JSONObject();
            _FAccountBookID.put("FNumber", "S01");
            model.put("FAccountBookID", _FAccountBookID);
            model.put("FDate", "2023-12-12");
            model.put("FDocumentStatus", "Z");


            JSONObject _FVOUCHERGROUPID = new JSONObject();
            _FVOUCHERGROUPID.put("FNumber", "PRE001");
            model.put("FVOUCHERGROUPID", _FVOUCHERGROUPID);

            JSONArray _FEntity = new JSONArray();


            JSONObject sub1 = new JSONObject();

            sub1.put("FEXPLANATION", "供应商摘要");
            //科目编码
            JSONObject _FACCOUNTID = new JSONObject();
            _FACCOUNTID.put("FNumber", "2202.02");
            sub1.put("FACCOUNTID", _FACCOUNTID);

            //币别
            JSONObject _FCURRENCYID = new JSONObject();
            _FCURRENCYID.put("FNumber", "PRE001");
            sub1.put("FCURRENCYID", _FCURRENCYID);

            //汇率类型
            JSONObject _FEXCHANGERATETYPE = new JSONObject();
            _FEXCHANGERATETYPE.put("FNumber", "HLTX01_SYS");
            sub1.put("FEXCHANGERATETYPE", _FEXCHANGERATETYPE);

            sub1.put("FEXCHANGERATE", "1");

            sub1.put("FAMOUNTFOR", 667.123);
            sub1.put("FDEBIT", 667.123);

            //核算对象
            JSONObject _FDetailID = new JSONObject();
            JSONObject _FDETAILID__FFLEX4 = new JSONObject();
            _FDETAILID__FFLEX4.put("FNumber", "1.001");
            _FDetailID.put("FDETAILID__FFLEX4", _FDETAILID__FFLEX4);
            sub1.put("FDetailID", _FDetailID);


            JSONObject sub2 = new JSONObject();
            sub2.put("FEXPLANATION", "2222");
            //科目编码
            JSONObject _FACCOUNTID2 = new JSONObject();
            _FACCOUNTID2.put("FNumber", "1001.01");
            sub2.put("FACCOUNTID", _FACCOUNTID2);

            //币别
            JSONObject _FCURRENCYID2 = new JSONObject();
            _FCURRENCYID2.put("FNumber", "PRE001");
            sub2.put("FCURRENCYID", _FCURRENCYID2);

            //汇率类型
            JSONObject _FEXCHANGERATETYPE2 = new JSONObject();
            _FEXCHANGERATETYPE2.put("FNumber", "HLTX01_SYS");
            sub2.put("FEXCHANGERATETYPE", _FEXCHANGERATETYPE2);

            sub2.put("FEXCHANGERATE", "1");

            sub2.put("FAMOUNTFOR", 667.123);
            sub2.put("FCREDIT", 667.123);

            //核算对象
            JSONObject _FDetailID2 = new JSONObject();
/*
            JSONObject _FDETAILID__FFLEX4_2 = new JSONObject();
            _FDETAILID__FFLEX4_2.put("FNumber", "1.001");
            _FDetailID2.put("FDETAILID__FFLEX4", _FDETAILID__FFLEX4_2);
            JSONObject _FDETAILID__FFLEX5_2 = new JSONObject();
            _FDETAILID__FFLEX5_2.put("FNumber", "03.02.0003");
            _FDetailID2.put("FDETAILID__FFLEX5", _FDETAILID__FFLEX5_2);
            sub2.put("FDetailID", _FDetailID2);*/


//需要保存的数据
// 如下字段可能需要根据自己实际值做修改
// FCustId FSalerId FMaterialId FUnitID
          /*  {
                "NeedUpDateFields": [],
                "NeedReturnFields": [],
                "IsDeleteEntry": true,
                    "SubSystemId": "",
                    "IsVerifyBaseDataField": false,
                    "IsEntryBatchFill": true,
                    "ValidateFlag": true,
                    "NumberSearch": true,
                    "IsAutoAdjustField": false,
                    "InterationFlags": "",
                    "IgnoreInterationFlag": "",
                    "IsControlPrecision": false,
                    "ValidateRepeatJson": false,
                    "Model": {
                "FDocumentStatus": "Z",
                        "FDate": "1900-01-01",
                        "FVOUCHERGROUPNO": "",
                        "FAccountBookID": {
                    "FNumber": ""
                },
                "FVOUCHERGROUPID": {
                    "FNumber": ""
                },
                "FEntity": [
                {
                    "FEXCHANGERATETYPE": {
                    "FNumber": ""
                },
                    "FCURRENCYID": {
                    "FNumber": ""
                },
                    "FACCOUNTID": {
                    "FNumber": ""
                }
                }
    ]
            }
            }*/
            _FEntity.add(sub1);
            _FEntity.add(sub2);
            //String sContent = "{\"Creator\":\"String\",\"NeedUpDateFields\":[\"FBillTypeID\",\"FDate\",\"FBusinessType\",\"FSaleOrgId\",\"FCustId\",\"FSettleCurrId\",\"FSalerId\",\"SAL_SaleOrder__FSaleOrderEntry\",\"FMaterialId\",\"FSettleOrgIds\",\"FUnitID\",\"FQty\",\"SAL_SaleOrder__FSaleOrderFinance\",\"FSettleCurrId\",\"FLocalCurrId\",\"FIsIncludedTax\",\"FBillTaxAmount\",\"FBillAmount\",\"FBillAllAmount\",\"FExchangeTypeId\",\"FExchangeRate\"],\"Model\":{\"FID\":0,\"FBillTypeID\":{\"FNumber\":\"XSDD01_SYS\"},\"FBusinessType\":\"NORMAL\",\"FSaleOrgId\":{\"FNUMBER\":\"100\"},\"FCustId\":{\"FNUMBER\":\"CUST0001\"},\"FSettleCurrId\":{\"FNUMBER\":\"PRE001\"},\"FSalerId\":{\"FNUMBER\":\"0002\"},\"SAL_SaleOrder__FSaleOrderFinance\":{\"FExchangeRate\":6.8123},\"SAL_SaleOrder__FSaleOrderEntry\":[{\"FMaterialId\":{\"FNUMBER\":\"001\"},\"FSettleOrgIds\":{\"FNUMBER\":\"100\"},\"FUnitID\":{\"FNumber\":\"个\"},\"FQty\":10}]}}";
            //String jsonData = "{\"NeedUpDateFields\":[],\"NeedReturnFields\":[],\"IsDeleteEntry\":\"true\",\"SubSystemId\":\"\",\"IsVerifyBaseDataField\":\"false\",\"IsEntryBatchFill\":\"true\",\"ValidateFlag\":\"true\",\"NumberSearch\":\"true\",\"IsAutoAdjustField\":\"false\",\"InterationFlags\":\"\",\"IgnoreInterationFlag\":\"\",\"IsControlPrecision\":\"false\",\"ValidateRepeatJson\":\"false\",\"Model\":{\"FVCHGROUPID\":0,\"FName\":\"\",\"FLimitMulti\":\"false\",\"FAcctTableId\":{\"FNumber\":\"\"},\"FNumber\":\"\",\"FAcctControl\":[{\"FEntryID\":0,\"FAcctNumber\":\"\",\"FDebit\":\"false\",\"FCredit\":\"false\",\"FDebitCredit\":\"false\",\"FDebitNo\":\"false\",\"FCreditNo\":\"false\",\"FDebitCreditNo\":\"false\"}]}}";
            model.put("FEntity", _FEntity);
            data.put("Model", model);
            System.out.println("data:" + JSON.toJSONString(data, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
            InvokeHelper.Save(sFormId, JSON.toJSONString(data));

            System.out.println("hola success");
        }
    }
}

==> ejc-accplat-impl-3.0.0-20240119.034106-128-sources.jar: com/ejianc/business/kingdee/test/InvokeTest.java <==
package com.ejianc.business.kingdee.test;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;

/**
 * @description: TODO
 * @author songlx
 * @date 2023/12/12
 * @version 1.0
 */
public class InvokeTest {

    // http://123.234.41.174:8090/k3cloud/html5/index.aspx
    //账号 ：徐慧/666666  选世纪阳光测试账套
    public static void main(String[] args) throws Exception {
        InvokeHelper.POST_K3CloudURL = "http://123.234.41.174:8090/K3Cloud/";
        String dbId = "6576a9828d11ae";
        String uid = "徐慧";
        String pwd = "666666";
        int lang = 2052;

        if (InvokeHelper.Login(dbId, uid, pwd, lang)) {

// 销售订单保存测试
// 业务对象Id
            String sFormId = "GL_VOUCHER";
            JSONObject data = new JSONObject();

            JSONObject model = new JSONObject();

            JSONObject _FAccountBookID = new JSONObject();
            _FAccountBookID.put("FNumber", "S01");
            model.put("FAccountBookID", _FAccountBookID);
            model.put("FDate", "2023-12-12");
           // model.put("FDocumentStatus", "Z");


            JSONObject _FVOUCHERGROUPID = new JSONObject();
            _FVOUCHERGROUPID.put("FNumber", "PRE001");
            //model.put("FVOUCHERGROUPID", _FVOUCHERGROUPID);

            JSONArray _FEntity = new JSONArray();


            JSONObject sub1 = new JSONObject();

            sub1.put("FEXPLANATION", "供应商摘要");
            //科目编码
            JSONObject _FACCOUNTID = new JSONObject();
            _FACCOUNTID.put("FNumber", "2202.02");
            sub1.put("FACCOUNTID", _FACCOUNTID);

            //币别
            JSONObject _FCURRENCYID = new JSONObject();
            _FCURRENCYID.put("FNumber", "PRE001");
            sub1.put("FCURRENCYID", _FCURRENCYID);

            //汇率类型
            JSONObject _FEXCHANGERATETYPE = new JSONObject();
            _FEXCHANGERATETYPE.put("FNumber", "HLTX01_SYS");
            sub1.put("FEXCHANGERATETYPE", _FEXCHANGERATETYPE);

            sub1.put("FEXCHANGERATE", "1");

            sub1.put("FAMOUNTFOR", 667.123);
            sub1.put("FDEBIT", 667.123);

            //核算对象
            JSONObject _FDetailID = new JSONObject();
            JSONObject _FDETAILID__FFLEX4 = new JSONObject();
            _FDETAILID__FFLEX4.put("FNumber", "1.001");
            _FDetailID.put("FDETAILID__FFLEX4", _FDETAILID__FFLEX4);
            sub1.put("FDetailID", _FDetailID);


            JSONObject sub2 = new JSONObject();
            sub2.put("FEXPLANATION", "2222");
            //科目编码
            JSONObject _FACCOUNTID2 = new JSONObject();
            _FACCOUNTID2.put("FNumber", "1001.01");
            sub2.put("FACCOUNTID", _FACCOUNTID2);

            //币别
            JSONObject _FCURRENCYID2 = new JSONObject();
            _FCURRENCYID2.put("FNumber", "PRE001");
            sub2.put("FCURRENCYID", _FCURRENCYID2);

            //汇率类型
            JSONObject _FEXCHANGERATETYPE2 = new JSONObject();
            _FEXCHANGERATETYPE2.put("FNumber", "HLTX01_SYS");
            sub2.put("FEXCHANGERATETYPE", _FEXCHANGERATETYPE2);

            sub2.put("FEXCHANGERATE", "1");

            sub2.put("FAMOUNTFOR", 667.123);
            sub2.put("FCREDIT", 667.123);

            //核算对象
            JSONObject _FDetailID2 = new JSONObject();
/*
            JSONObject _FDETAILID__FFLEX4_2 = new JSONObject();
            _FDETAILID__FFLEX4_2.put("FNumber", "1.001");
            _FDetailID2.put("FDETAILID__FFLEX4", _FDETAILID__FFLEX4_2);
            JSONObject _FDETAILID__FFLEX5_2 = new JSONObject();
            _FDETAILID__FFLEX5_2.put("FNumber", "03.02.0003");
            _FDetailID2.put("FDETAILID__FFLEX5", _FDETAILID__FFLEX5_2);
            sub2.put("FDetailID", _FDetailID2);*/


//需要保存的数据
// 如下字段可能需要根据自己实际值做修改
// FCustId FSalerId FMaterialId FUnitID
          /*  {
                "NeedUpDateFields": [],
                "NeedReturnFields": [],
                "IsDeleteEntry": true,
                    "SubSystemId": "",
                    "IsVerifyBaseDataField": false,
                    "IsEntryBatchFill": true,
                    "ValidateFlag": true,
                    "NumberSearch": true,
                    "IsAutoAdjustField": false,
                    "InterationFlags": "",
                    "IgnoreInterationFlag": "",
                    "IsControlPrecision": false,
                    "ValidateRepeatJson": false,
                    "Model": {
                "FDocumentStatus": "Z",
                        "FDate": "1900-01-01",
                        "FVOUCHERGROUPNO": "",
                        "FAccountBookID": {
                    "FNumber": ""
                },
                "FVOUCHERGROUPID": {
                    "FNumber": ""
                },
                "FEntity": [
                {
                    "FEXCHANGERATETYPE": {
                    "FNumber": ""
                },
                    "FCURRENCYID": {
                    "FNumber": ""
                },
                    "FACCOUNTID": {
                    "FNumber": ""
                }
                }
    ]
            }
            }*/
            _FEntity.add(sub1);
            _FEntity.add(sub2);
            //String sContent = "{\"Creator\":\"String\",\"NeedUpDateFields\":[\"FBillTypeID\",\"FDate\",\"FBusinessType\",\"FSaleOrgId\",\"FCustId\",\"FSettleCurrId\",\"FSalerId\",\"SAL_SaleOrder__FSaleOrderEntry\",\"FMaterialId\",\"FSettleOrgIds\",\"FUnitID\",\"FQty\",\"SAL_SaleOrder__FSaleOrderFinance\",\"FSettleCurrId\",\"FLocalCurrId\",\"FIsIncludedTax\",\"FBillTaxAmount\",\"FBillAmount\",\"FBillAllAmount\",\"FExchangeTypeId\",\"FExchangeRate\"],\"Model\":{\"FID\":0,\"FBillTypeID\":{\"FNumber\":\"XSDD01_SYS\"},\"FBusinessType\":\"NORMAL\",\"FSaleOrgId\":{\"FNUMBER\":\"100\"},\"FCustId\":{\"FNUMBER\":\"CUST0001\"},\"FSettleCurrId\":{\"FNUMBER\":\"PRE001\"},\"FSalerId\":{\"FNUMBER\":\"0002\"},\"SAL_SaleOrder__FSaleOrderFinance\":{\"FExchangeRate\":6.8123},\"SAL_SaleOrder__FSaleOrderEntry\":[{\"FMaterialId\":{\"FNUMBER\":\"001\"},\"FSettleOrgIds\":{\"FNUMBER\":\"100\"},\"FUnitID\":{\"FNumber\":\"个\"},\"FQty\":10}]}}";
            //String jsonData = "{\"NeedUpDateFields\":[],\"NeedReturnFields\":[],\"IsDeleteEntry\":\"true\",\"SubSystemId\":\"\",\"IsVerifyBaseDataField\":\"false\",\"IsEntryBatchFill\":\"true\",\"ValidateFlag\":\"true\",\"NumberSearch\":\"true\",\"IsAutoAdjustField\":\"false\",\"InterationFlags\":\"\",\"IgnoreInterationFlag\":\"\",\"IsControlPrecision\":\"false\",\"ValidateRepeatJson\":\"false\",\"Model\":{\"FVCHGROUPID\":0,\"FName\":\"\",\"FLimitMulti\":\"false\",\"FAcctTableId\":{\"FNumber\":\"\"},\"FNumber\":\"\",\"FAcctControl\":[{\"FEntryID\":0,\"FAcctNumber\":\"\",\"FDebit\":\"false\",\"FCredit\":\"false\",\"FDebitCredit\":\"false\",\"FDebitNo\":\"false\",\"FCreditNo\":\"false\",\"FDebitCreditNo\":\"false\"}]}}";
            model.put("FEntity", _FEntity);
            data.put("Model", model);
            System.out.println("data:" + JSON.toJSONString(data, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
            InvokeHelper.Save(sFormId, JSON.toJSONString(data));

            System.out.println("hola success");
        }
    }
}
